==> haskell-drbg-0.5.5-50-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DRBG
version: 0.5.5
id: DRBG-0.5.5-EfS4oTnYnT76hqaGFzuSUC
key: DRBG-0.5.5-EfS4oTnYnT76hqaGFzuSUC
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: Deterministic random bit generator (aka RNG, PRNG) based
          HMACs, Hashes, and Ciphers.
description:
    Cryptographically secure RNGs
category: Cryptography
abi: f51704f82ce658169f91c4071b767bf0
exposed: True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types
hidden-modules: Crypto.Random.DRBG.HashDF
import-dirs: /usr/lib/ghc-8.6.5/site-local/DRBG-0.5.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/DRBG-0.5.5
hs-libraries: HSDRBG-0.5.5-EfS4oTnYnT76hqaGFzuSUC
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.0-DifhRWa8By0JYDe2id7eOT
    cipher-aes128-0.7.0.4-MMMGge605YFIJqo6byj30
    crypto-api-0.13.3-BkUbrvVpNfiChPu2ZO0fOd
    cryptohash-cryptoapi-0.1.4-A0TVRjmUbBjCJ4atElNGIq
    entropy-0.4.1.4-23NMAjgKyCo3F1ZCvvDJOh mtl-2.2.2
    parallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ
    prettyclass-1.0.0.0-TEwWRphxli3LO8yb54rr0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html: /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-drbg-0.5.5-51-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DRBG
version: 0.5.5
id: DRBG-0.5.5-IKH7FIrj1AL93k95Fuoqmg
key: DRBG-0.5.5-IKH7FIrj1AL93k95Fuoqmg
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: Deterministic random bit generator (aka RNG, PRNG) based
          HMACs, Hashes, and Ciphers.
description:
    Cryptographically secure RNGs
category: Cryptography
abi: b505e1a661f353115c9ed3ee7edca8b8
exposed: True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types
hidden-modules: Crypto.Random.DRBG.HashDF
import-dirs: /usr/lib/ghc-8.6.5/site-local/DRBG-0.5.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/DRBG-0.5.5
hs-libraries: HSDRBG-0.5.5-IKH7FIrj1AL93k95Fuoqmg
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.0-DifhRWa8By0JYDe2id7eOT
    cipher-aes128-0.7.0.4-MMMGge605YFIJqo6byj30
    crypto-api-0.13.3-BkUbrvVpNfiChPu2ZO0fOd
    cryptohash-cryptoapi-0.1.4-2dm3EcMNEsW3UybrzEoa3m
    entropy-0.4.1.4-23NMAjgKyCo3F1ZCvvDJOh mtl-2.2.2
    parallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ
    prettyclass-1.0.0.0-TEwWRphxli3LO8yb54rr0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html: /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
